@@ -13,12 +13,36 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.utils import formatdate
 
-# python 3 doesn't have the basestring anymore. How rude.
-string_type = basestring if sys.version_info[0] == 2 else str
+
+PY2 = sys.version_info[0] == 2
+
+if PY2:
+    string_type = basestring
+    iteritems = lambda d: d.iteritems()
+else:
+    string_type = str
+    iteritems = lambda d: d.items()
+
 
 class Email(object):
     def __init__(self, recipients, subject, body=None, html_body=None,
-            charset='utf8', fields=None):
+                 charset='utf8', fields=None):
+        """
+        Object representation of an email. Contains a recipient, subject,
+        conditionally a body or HTML body.
+
+        Arguments:
+            recipients - list of strings of the email addresses of the
+                         recipients. May also be a string containing a single
+                         email address.
+            subject - Subject of the email.
+            body - Plain-text body.
+            html_body - Rich-text body.
+            charset - charset to use for encoding the `body` and `html_body`
+                      attributes.
+            fields - any additional headers you want to add to the email message.
+        """
+
         iter(recipients)
 
         if isinstance(recipients, string_type):
@@ -39,11 +63,7 @@ class Email(object):
         self.body = body
         self.html_body = html_body
         self.charset = charset
-
-        if fields:
-            self.fields = fields
-        else:
-            self.fields = dict()
+        self.fields = fields or {}
 
     def as_mime(self, attachments=()):
         msg = MIMEMultipart('alternative')
@@ -51,7 +71,7 @@ class Email(object):
         msg['Date'] = formatdate(localtime=True)
         msg['Subject'] = self.subject
 
-        for key, value in self.fields.iteritems():
+        for key, value in iteritems(self.fields):
             msg[key] = value
 
         if self.body:
@@ -67,6 +87,7 @@ class Email(object):
 
         return msg
 
+
 class Attachment(object):
     '''Attachment for an email'''
 
@@ -80,6 +101,7 @@ class Attachment(object):
     def read(self):
         return self.raw
 
+
 class Outbox(object):
     '''Thin wrapper around the SMTP and SMTP_SSL classes from the smtplib module.'''
 
@@ -117,12 +139,17 @@ class Outbox(object):
         if mode == 'TLS':
             smtp.starttls()
 
-        smtp.login(self.username, self.password)
+        self.authenticate(smtp)
+
         return smtp
 
     def connect(self):
         self._conn = self._login()
 
+    def authenticate(self, smtp):
+        """Perform login with the given smtplib.SMTP instance."""
+        smtp.login(self.username, self.password)
+
     def disconnect(self):
         self._conn.quit()
 
@@ -141,11 +168,11 @@ class Outbox(object):
 
         if self._conn:
             self._conn.sendmail(self.username, email.recipients,
-                    msg.as_string())
+                                msg.as_string())
         else:
             with self:
                 self._conn.sendmail(self.username, email.recipients,
-                        msg.as_string())
+                                    msg.as_string())
 
     def sender_address(self):
         '''Return the sender address.
@@ -158,6 +185,19 @@ class Outbox(object):
         '''
         return self.username
 
+
+class AnonymousOutbox(Outbox):
+    """Outbox subclass suitable for SMTP servers that do not (or will not)
+    perform authentication.
+    """
+    def __init__(self, *args, **kwargs):
+        super(AnonymousOutbox, self).__init__('', '', *args, **kwargs)
+
+    def authenticate(self, smtp):
+        """Perform no authentication as the server does not require it."""
+        pass
+
+
 def add_attachment(message, attachment):
     '''Attach an attachment to a message as a side effect.
 
@@ -171,6 +211,6 @@ def add_attachment(message, attachment):
     part.set_payload(data)
     encoders.encode_base64(part)
     part.add_header('Content-Disposition', 'attachment',
-            filename=attachment.name)
+                    filename=attachment.name)
 
     message.attach(part)
